==> adams-weka-0.3.23-test-sources.jar: adams/test/TmpExperimentFile.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * TmpExperimentFile.java
 * Copyright (C) 2010 University of Waikato, Hamilton, New Zealand
 */
package adams.test;

import adams.data.WekaExperimentFile;

/**
 * A simple file handler class (for experiment files) that automatically places the
 * file in the system's tmp directory. But the user still needs to delete the
 * file manually when it's no longer used.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 4584 $
 */
public class TmpExperimentFile
  extends WekaExperimentFile {

  /** for serialization. */
  private static final long serialVersionUID = 7689124528783850812L;

  /**
   * Creates a new <code>File</code> instance by converting the given
   * pathname string into an abstract pathname.  If the given string is
   * the empty string, then the result is the empty abstract pathname.
   *
   * @param   pathname  A pathname string
   */
  public TmpExperimentFile(String pathname) {
    super(System.getProperty("java.io.tmpdir") + separator + pathname);
  }
}

==> adams-weka-0.4.11-test-sources.jar: adams/test/TmpExperimentFile.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * TmpExperimentFile.java
 * Copyright (C) 2010 University of Waikato, Hamilton, New Zealand
 */
package adams.test;

import adams.core.io.TempUtils;
import adams.data.WekaExperimentFile;

/**
 * A simple file handler class (for experiment files) that automatically places the
 * file in the system's tmp directory. But the user still needs to delete the
 * file manually when it's no longer used.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 10802 $
 */
public class TmpExperimentFile
  extends WekaExperimentFile {

  /** for serialization. */
  private static final long serialVersionUID = 7689124528783850812L;

  /**
   * Creates a new <code>File</code> instance by converting the given
   * pathname string into an abstract pathname.  If the given string is
   * the empty string, then the result is the empty abstract pathname.
   *
   * @param   pathname  A pathname string
   */
  public TmpExperimentFile(String pathname) {
    super(TempUtils.createTempFile(pathname));
  }
}
